==> react-layout-grid-2.0.0.tgz: package/lib/gridItem/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { useMemo } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { BASE_CLASS, CELL_NUMBERS, BREAKPOINTS } from '../settings';
/**
 * getColSpanClassNamesTransform: gets the classes of each media query
 * depending on the combination of its values. breakpoint key values
 * are preferred over colSpan values
 * @param colSpan
 * @param otherProps {xxs, xs, s, m, l, xl, xxl}
 * @returns {null|string} – classnames for the column span
 */

import { jsx as _jsx } from "react/jsx-runtime";
export var getColSpanClassNamesTransform = function getColSpanClassNamesTransform(_ref) {
  var colSpan = _ref.colSpan,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["colSpan"]);

  var getValidBreakpointValue = function getValidBreakpointValue(colSpanValue, breakpointValue) {
    return CELL_NUMBERS.includes(breakpointValue) ? breakpointValue : false || CELL_NUMBERS.includes(colSpanValue) ? colSpanValue : false;
  };

  var response = Object.values(BREAKPOINTS).reduce(function (acc, breakpointName) {
    var value;

    if (breakpointName === 'xxs') {
      value = getValidBreakpointValue(typeof colSpan === 'number' && CELL_NUMBERS.includes(colSpan) ? colSpan : colSpan == null ? void 0 : colSpan[breakpointName], otherProps[breakpointName]);
    } else {
      value = getValidBreakpointValue(colSpan == null ? void 0 : colSpan[breakpointName], otherProps[breakpointName]);
    }

    return value ? (acc + " " + BASE_CLASS + "-item--" + breakpointName + "-" + value).trim() : acc;
  }, '');
  return response === '' ? null : response;
};
export default function LayoutGridItem(_ref2) {
  var children = _ref2.children,
      colSpan = _ref2.colSpan,
      l = _ref2.l,
      lOffset = _ref2.lOffset,
      m = _ref2.m,
      mOffset = _ref2.mOffset,
      s = _ref2.s,
      sOffset = _ref2.sOffset,
      xl = _ref2.xl,
      xlOffset = _ref2.xlOffset,
      xs = _ref2.xs,
      xsOffset = _ref2.xsOffset,
      xxl = _ref2.xxl,
      xxlOffset = _ref2.xxlOffset,
      xxs = _ref2.xxs,
      xxsOffset = _ref2.xxsOffset;
  var spanClassnames = useMemo(function () {
    return getColSpanClassNamesTransform({
      colSpan: colSpan,
      xxl: xxl,
      xl: xl,
      l: l,
      m: m,
      s: s,
      xs: xs,
      xxs: xxs
    });
  }, [colSpan, xxl, xl, l, m, s, xs, xxs]);
  var classNames = cx(BASE_CLASS + "-item", spanClassnames, xxsOffset && BASE_CLASS + "-item--xxsOffset-" + xxsOffset, xsOffset && BASE_CLASS + "-item--xsOffset-" + xsOffset, sOffset && BASE_CLASS + "-item--sOffset-" + sOffset, mOffset && BASE_CLASS + "-item--mOffset-" + mOffset, lOffset && BASE_CLASS + "-item--lOffset-" + lOffset, xlOffset && BASE_CLASS + "-item--xlOffset-" + xlOffset, xxlOffset && BASE_CLASS + "-item--xxlOffset-" + xxlOffset);
  return /*#__PURE__*/_jsx("div", {
    className: classNames,
    children: children
  });
}
LayoutGridItem.displayName = 'LayoutGridItem';

==> react-layout-grid-2.2.0.tgz: package/lib/gridItem/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { useMemo } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { BASE_CLASS, CELL_NUMBERS, BREAKPOINTS } from '../settings';
/**
 * getColSpanClassNamesTransform: gets the classes of each media query
 * depending on the combination of its values. breakpoint key values
 * are preferred over colSpan values
 * @param colSpan
 * @param otherProps {xxs, xs, s, m, l, xl, xxl}
 * @returns {null|string} – classnames for the column span
 */

import { jsx as _jsx } from "react/jsx-runtime";
export var getColSpanClassNamesTransform = function getColSpanClassNamesTransform(_ref) {
  var colSpan = _ref.colSpan,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["colSpan"]);

  var getValidBreakpointValue = function getValidBreakpointValue(colSpanValue, breakpointValue) {
    return CELL_NUMBERS.includes(breakpointValue) ? breakpointValue : false || CELL_NUMBERS.includes(colSpanValue) ? colSpanValue : false;
  };

  var response = Object.values(BREAKPOINTS).reduce(function (acc, breakpointName) {
    var value;

    if (breakpointName === 'xxs') {
      value = getValidBreakpointValue(typeof colSpan === 'number' && CELL_NUMBERS.includes(colSpan) ? colSpan : colSpan == null ? void 0 : colSpan[breakpointName], otherProps[breakpointName]);
    } else {
      value = getValidBreakpointValue(colSpan == null ? void 0 : colSpan[breakpointName], otherProps[breakpointName]);
    }

    return value ? (acc + " " + BASE_CLASS + "-item--" + breakpointName + "-" + value).trim() : acc;
  }, '');
  return response === '' ? null : response;
};
export default function LayoutGridItem(_ref2) {
  var children = _ref2.children,
      _ref2$colSpan = _ref2.colSpan,
      colSpan = _ref2$colSpan === void 0 ? 1 : _ref2$colSpan,
      l = _ref2.l,
      lOffset = _ref2.lOffset,
      m = _ref2.m,
      mOffset = _ref2.mOffset,
      s = _ref2.s,
      sOffset = _ref2.sOffset,
      xl = _ref2.xl,
      xlOffset = _ref2.xlOffset,
      xs = _ref2.xs,
      xsOffset = _ref2.xsOffset,
      xxl = _ref2.xxl,
      xxlOffset = _ref2.xxlOffset,
      xxs = _ref2.xxs,
      xxsOffset = _ref2.xxsOffset;
  var spanClassnames = useMemo(function () {
    return getColSpanClassNamesTransform({
      colSpan: colSpan,
      xxl: xxl,
      xl: xl,
      l: l,
      m: m,
      s: s,
      xs: xs,
      xxs: xxs
    });
  }, [colSpan, xxl, xl, l, m, s, xs, xxs]);
  var classNames = cx(BASE_CLASS + "-item", spanClassnames, xxsOffset && BASE_CLASS + "-item--xxsOffset-" + xxsOffset, xsOffset && BASE_CLASS + "-item--xsOffset-" + xsOffset, sOffset && BASE_CLASS + "-item--sOffset-" + sOffset, mOffset && BASE_CLASS + "-item--mOffset-" + mOffset, lOffset && BASE_CLASS + "-item--lOffset-" + lOffset, xlOffset && BASE_CLASS + "-item--xlOffset-" + xlOffset, xxlOffset && BASE_CLASS + "-item--xxlOffset-" + xxlOffset);
  return /*#__PURE__*/_jsx("div", {
    className: classNames,
    children: children
  });
}
LayoutGridItem.displayName = 'LayoutGridItem';
